==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/cs/dangi.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "nyní",
	"field-quarter-relative+-1": "minulé čtvrtletí",
	"field-weekday": "den v týdnu",
	"field-mon-narrow-relative+0": "toto pondělí",
	"field-mon-narrow-relative+1": "příští pondělí",
	"field-day-narrow-relative+0": "dnes",
	"field-day-narrow-relative+1": "zítra",
	"field-day-short-relative+0": "dnes",
	"field-day-narrow-relative+2": "pozítří",
	"field-day-short-relative+1": "zítra",
	"field-day-short-relative+2": "pozítří",
	"field-wed-relative+0": "tuto středu",
	"field-wed-relative+1": "příští středu",
	"field-week-short": "týd.",
	"field-year-short": "r.",
	"field-tue-relative+-1": "minulé úterý",
	"field-thu-narrow-relative+-1": "minulý čtvrtek",
	"field-hour-relative+0": "tuto hodinu",
	"field-quarter-narrow": "Q",
	"field-fri-relative+-1": "minulý pátek",
	"field-hour-short": "h",
	"field-wed-relative+-1": "minulou středu",
	"months-format-wide": [
		"První měsíc",
		"Druhý měsíc",
		"Třetí měsíc",
		"Čtvrtý měsíc",
		"Pátý měsíc",
		"Šestý měsíc",
		"Sedmý měsíc",
		"Osmý měsíc",
		"Devátý měsíc",
		"Desátý měsíc",
		"Jedenáctý měsíc",
		"Dvanáctý měsíc"
	],
	"field-mon-short-relative+-1": "minulé pondělí",
	"field-day-short-relative+-1": "včera",
	"field-thu-relative+-1": "minulý čtvrtek",
	"field-day-short-relative+-2": "předevčírem",
	"field-era": "letopočet",
	"months-standAlone-wide": [
		"První měsíc",
		"Druhý měsíc",
		"Třetí měsíc",
		"Čtvrtý měsíc",
		"Pátý měsíc",
		"Šestý měsíc",
		"Sedmý měsíc",
		"Osmý měsíc",
		"Devátý měsíc",
		"Desátý měsíc",
		"Jedenáctý měsíc",
		"Dvanáctý měsíc"
	],
	"field-sat-narrow-relative+0": "tuto sobotu",
	"field-sat-narrow-relative+1": "příští sobotu",
	"field-year": "rok",
	"field-hour": "hodina",
	"field-day-narrow-relative+-1": "včera",
	"months-format-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-sat-relative+0": "tuto sobotu",
	"field-day-narrow-relative+-2": "předevčírem",
	"field-sat-relative+1": "příští sobotu",
	"field-sat-short-relative+-1": "minulou sobotu",
	"field-week-narrow-relative+-1": "minulý týd.",
	"field-minute-narrow": "min",
	"field-day-relative+0": "dnes",
	"field-day-relative+1": "zítra",
	"field-thu-relative+0": "tento čtvrtek",
	"field-day-relative+2": "pozítří",
	"field-mon-narrow-relative+-1": "minulé pondělí",
	"field-wed-narrow-relative+0": "tuto středu",
	"field-thu-relative+1": "příští čtvrtek",
	"months-standAlone-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-wed-narrow-relative+1": "příští středu",
	"field-mon-short-relative+0": "toto pondělí",
	"field-mon-short-relative+1": "příští pondělí",
	"field-wed-short-relative+-1": "minulou středu",
	"field-fri-narrow-relative+-1": "minulý pátek",
	"field-hour-narrow": "h",
	"field-year-narrow": "r.",
	"field-tue-short-relative+0": "toto úterý",
	"field-tue-short-relative+1": "příští úterý",
	"field-minute-short": "min",
	"field-day-narrow": "den",
	"field-year-narrow-relative+-1": "minulý rok",
	"field-wed-short-relative+0": "tuto středu",
	"field-wed-short-relative+1": "příští středu",
	"field-sun-relative+0": "tuto neděli",
	"field-sun-relative+1": "příští neděli",
	"field-year-short-relative+0": "tento rok",
	"field-minute": "minuta",
	"field-month-short": "měs.",
	"field-year-short-relative+1": "příští rok",
	"field-dayperiod": "část dne",
	"field-day-relative+-1": "včera",
	"field-day-relative+-2": "předevčírem",
	"field-minute-relative+0": "tuto minutu",
	"field-week-narrow": "týd.",
	"field-wed-narrow-relative+-1": "minulou středu",
	"field-day-short": "den",
	"field-quarter-relative+0": "toto čtvrtletí",
	"field-quarter-relative+1": "příští čtvrtletí",
	"field-fri-relative+0": "tento pátek",
	"field-fri-relative+1": "příští pátek",
	"field-day": "den",
	"field-second-narrow": "s",
	"field-zone": "časové pásmo",
	"field-year-relative+-1": "minulý rok",
	"field-month-relative+-1": "minulý měsíc",
	"field-thu-short-relative+0": "tento čtvrtek",
	"field-thu-short-relative+1": "příští čtvrtek",
	"field-quarter": "čtvrtletí",
	"field-second-narrow-relative+0": "nyní",
	"field-month": "měsíc",
	"field-tue-relative+0": "toto úterý",
	"field-tue-relative+1": "příští úterý",
	"field-fri-narrow-relative+0": "tento pátek",
	"field-fri-narrow-relative+1": "příští pátek",
	"field-fri-short-relative+-1": "minulý pátek",
	"field-year-narrow-relative+0": "tento rok",
	"field-sun-narrow-relative+-1": "minulou neděli",
	"field-year-narrow-relative+1": "příští rok",
	"field-week-narrow-relative+0": "tento týd.",
	"field-week-narrow-relative+1": "příští týd.",
	"field-sun-narrow-relative+0": "tuto neděli",
	"field-thu-narrow-relative+0": "tento čtvrtek",
	"field-sun-narrow-relative+1": "příští neděli",
	"field-thu-narrow-relative+1": "příští čtvrtek",
	"field-tue-narrow-relative+0": "toto úterý",
	"field-mon-relative+0": "toto pondělí",
	"field-tue-narrow-relative+1": "příští úterý",
	"field-week-short-relative+-1": "minulý týd.",
	"field-mon-relative+1": "příští pondělí",
	"field-tue-narrow-relative+-1": "minulé úterý",
	"field-second-short": "s",
	"field-second": "sekunda",
	"field-fri-short-relative+0": "tento pátek",
	"field-sat-relative+-1": "minulou sobotu",
	"field-fri-short-relative+1": "příští pátek",
	"field-sun-relative+-1": "minulou neděli",
	"field-month-relative+0": "tento měsíc",
	"field-month-relative+1": "příští měsíc",
	"field-week-short-relative+0": "tento týd.",
	"field-week-short-relative+1": "příští týd.",
	"field-week": "týden",
	"field-sat-short-relative+0": "tuto sobotu",
	"field-sat-short-relative+1": "příští sobotu",
	"field-year-relative+0": "tento rok",
	"field-week-relative+-1": "minulý týden",
	"field-year-relative+1": "příští rok",
	"field-year-short-relative+-1": "minulý rok",
	"field-quarter-short": "Q",
	"field-sun-short-relative+-1": "minulou neděli",
	"field-thu-short-relative+-1": "minulý čtvrtek",
	"field-tue-short-relative+-1": "minulé úterý",
	"field-mon-relative+-1": "minulé pondělí",
	"field-sat-narrow-relative+-1": "minulou sobotu",
	"field-month-narrow": "měs.",
	"field-week-relative+0": "tento týden",
	"field-sun-short-relative+0": "tuto neděli",
	"field-second-short-relative+0": "nyní",
	"field-week-relative+1": "příští týden",
	"field-sun-short-relative+1": "příští neděli"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/cs/dangi.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "toto čtvrtletí",
	"field-quarter-short-relative+1": "příští čtvrtletí",
	"field-tue-relative+-1": "minulé úterý",
	"field-year": "rok",
	"field-wed-relative+0": "tuto středu",
	"field-wed-relative+1": "příští středu",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "minulý měs.",
	"field-tue-narrow-relative+0": "toto úterý",
	"field-tue-narrow-relative+1": "příští úterý",
	"field-thu-short-relative+0": "tento čtvrtek",
	"field-day-short-relative+-1": "včera",
	"field-thu-short-relative+1": "příští čtvrtek",
	"field-day-relative+0": "dnes",
	"field-day-short-relative+-2": "předevčírem",
	"field-day-relative+1": "zítra",
	"field-week-narrow-relative+0": "tento týd.",
	"field-day-relative+2": "pozítří",
	"field-week-narrow-relative+1": "příští týd.",
	"field-wed-narrow-relative+-1": "minulou středu",
	"field-year-narrow": "r.",
	"field-era-short": "letop.",
	"field-year-narrow-relative+0": "tento rok",
	"field-tue-relative+0": "toto úterý",
	"field-year-narrow-relative+1": "příští rok",
	"field-tue-relative+1": "příští úterý",
	"field-weekdayOfMonth": "den týdne v měsíci",
	"field-second-short": "s",
	"field-weekdayOfMonth-narrow": "d. týd. v měs.",
	"field-week-relative+0": "tento týden",
	"field-month-relative+0": "tento měsíc",
	"field-week-relative+1": "příští týden",
	"field-month-relative+1": "příští měsíc",
	"field-sun-narrow-relative+0": "tuto neděli",
	"field-mon-short-relative+0": "toto pondělí",
	"field-sun-narrow-relative+1": "příští neděli",
	"field-mon-short-relative+1": "příští pondělí",
	"field-second-relative+0": "nyní",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-weekOfMonth": "týden v měsíci",
	"field-month-short": "měs.",
	"field-day": "den",
	"field-dayOfYear-short": "den v r.",
	"field-year-relative+-1": "minulý rok",
	"field-sat-short-relative+-1": "minulou sobotu",
	"field-hour-relative+0": "tuto hodinu",
	"field-second-short-relative+0": "nyní",
	"field-wed-relative+-1": "minulou středu",
	"field-sat-narrow-relative+-1": "minulou sobotu",
	"field-second": "sekunda",
	"field-hour-short-relative+0": "tuto hodinu",
	"field-quarter": "čtvrtletí",
	"field-week-short": "týd.",
	"field-day-narrow-relative+0": "dnes",
	"field-day-narrow-relative+1": "zítra",
	"field-day-narrow-relative+2": "pozítří",
	"field-tue-short-relative+0": "toto úterý",
	"field-tue-short-relative+1": "příští úterý",
	"field-month-short-relative+-1": "minulý měs.",
	"field-mon-relative+-1": "minulé pondělí",
	"field-month": "měsíc",
	"field-day-narrow": "den",
	"field-minute-short": "min",
	"field-dayperiod": "část dne",
	"field-sat-short-relative+0": "tuto sobotu",
	"field-sat-short-relative+1": "příští sobotu",
	"field-second-narrow": "s",
	"field-mon-relative+0": "toto pondělí",
	"field-mon-relative+1": "příští pondělí",
	"field-day-narrow-relative+-1": "včera",
	"field-year-short": "r.",
	"field-day-narrow-relative+-2": "předevčírem",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-quarter-relative+-1": "minulé čtvrtletí",
	"field-dayperiod-narrow": "část d.",
	"field-week-narrow-relative+-1": "minulý týd.",
	"field-dayOfYear": "den v roce",
	"field-sat-relative+-1": "minulou sobotu",
	"field-hour": "hodina",
	"field-minute-narrow-relative+0": "tuto minutu",
	"months-format-wide": [
		"První měsíc",
		"Druhý měsíc",
		"Třetí měsíc",
		"Čtvrtý měsíc",
		"Pátý měsíc",
		"Šestý měsíc",
		"Sedmý měsíc",
		"Osmý měsíc",
		"Devátý měsíc",
		"Desátý měsíc",
		"Jedenáctý měsíc",
		"Dvanáctý měsíc"
	],
	"field-month-relative+-1": "minulý měsíc",
	"field-quarter-short": "Q",
	"field-sat-narrow-relative+0": "tuto sobotu",
	"field-fri-relative+0": "tento pátek",
	"field-sat-narrow-relative+1": "příští sobotu",
	"field-fri-relative+1": "příští pátek",
	"field-month-narrow-relative+0": "tento měs.",
	"field-month-narrow-relative+1": "příští měs.",
	"field-sun-short-relative+0": "tuto neděli",
	"field-sun-short-relative+1": "příští neděli",
	"field-week-relative+-1": "minulý týden",
	"field-quarter-short-relative+-1": "minulé čtvrtletí",
	"field-minute-short-relative+0": "tuto minutu",
	"months-format-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-quarter-relative+0": "toto čtvrtletí",
	"field-minute-relative+0": "tuto minutu",
	"field-quarter-relative+1": "příští čtvrtletí",
	"field-wed-short-relative+-1": "minulou středu",
	"field-thu-short-relative+-1": "minulý čtvrtek",
	"field-year-narrow-relative+-1": "minulý rok",
	"field-mon-narrow-relative+-1": "minulé pondělí",
	"field-thu-narrow-relative+-1": "minulý čtvrtek",
	"field-tue-narrow-relative+-1": "minulé úterý",
	"field-weekOfMonth-short": "týd. v m.",
	"field-wed-short-relative+0": "tuto středu",
	"months-standAlone-wide": [
		"První měsíc",
		"Druhý měsíc",
		"Třetí měsíc",
		"Čtvrtý měsíc",
		"Pátý měsíc",
		"Šestý měsíc",
		"Sedmý měsíc",
		"Osmý měsíc",
		"Devátý měsíc",
		"Desátý měsíc",
		"Jedenáctý měsíc",
		"Dvanáctý měsíc"
	],
	"field-wed-short-relative+1": "příští středu",
	"field-sun-relative+-1": "minulou neděli",
	"field-second-narrow-relative+0": "nyní",
	"field-weekday": "den v týdnu",
	"field-day-short-relative+0": "dnes",
	"field-quarter-narrow-relative+0": "toto čtvrtletí",
	"field-sat-relative+0": "tuto sobotu",
	"field-day-short-relative+1": "zítra",
	"field-quarter-narrow-relative+1": "příští čtvrtletí",
	"field-day-short-relative+2": "pozítří",
	"field-sat-relative+1": "příští sobotu",
	"field-week-short-relative+0": "tento týd.",
	"field-week-short-relative+1": "příští týd.",
	"months-standAlone-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-dayOfYear-narrow": "d. v r.",
	"field-month-short-relative+0": "tento měs.",
	"field-month-short-relative+1": "příští měs.",
	"field-weekdayOfMonth-short": "den týd. v měs.",
	"field-zone-narrow": "pásmo",
	"field-thu-narrow-relative+0": "tento čtvrtek",
	"field-thu-narrow-relative+1": "příští čtvrtek",
	"field-sun-narrow-relative+-1": "minulou neděli",
	"field-mon-short-relative+-1": "minulé pondělí",
	"field-thu-relative+0": "tento čtvrtek",
	"field-thu-relative+1": "příští čtvrtek",
	"field-fri-short-relative+-1": "minulý pátek",
	"field-thu-relative+-1": "minulý čtvrtek",
	"field-week": "týden",
	"field-wed-narrow-relative+0": "tuto středu",
	"field-wed-narrow-relative+1": "příští středu",
	"field-quarter-narrow-relative+-1": "minulé čtvrtletí",
	"field-year-short-relative+0": "tento rok",
	"field-dayperiod-short": "část dne",
	"field-year-short-relative+1": "příští rok",
	"field-fri-short-relative+0": "tento pátek",
	"field-fri-short-relative+1": "příští pátek",
	"field-week-short-relative+-1": "minulý týd.",
	"field-hour-narrow-relative+0": "tuto hodinu",
	"field-hour-short": "h",
	"field-zone-short": "čas. pásmo",
	"field-month-narrow": "měs.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "minulý pátek",
	"field-year-relative+0": "tento rok",
	"field-year-relative+1": "příští rok",
	"field-era-narrow": "let.",
	"field-fri-relative+-1": "minulý pátek",
	"field-tue-short-relative+-1": "minulé úterý",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "toto pondělí",
	"field-mon-narrow-relative+1": "příští pondělí",
	"field-year-short-relative+-1": "minulý rok",
	"field-zone": "časové pásmo",
	"field-weekOfMonth-narrow": "týd. v m.",
	"field-weekday-narrow": "d. v týd.",
	"field-quarter-narrow": "Q",
	"field-sun-short-relative+-1": "minulou neděli",
	"field-day-relative+-1": "včera",
	"field-day-relative+-2": "předevčírem",
	"field-weekday-short": "den v týd.",
	"field-sun-relative+0": "tuto neděli",
	"field-sun-relative+1": "příští neděli",
	"field-day-short": "den",
	"field-week-narrow": "týd.",
	"field-era": "letopočet",
	"field-fri-narrow-relative+0": "tento pátek",
	"field-fri-narrow-relative+1": "příští pátek"
}
//end v1.x content
);
